@@ -1,5 +1,5 @@
 package App::bmkpasswd;
-$App::bmkpasswd::VERSION = '2.010001';
+$App::bmkpasswd::VERSION = '2.011001';
 use strictures 2;
 use Carp;
 use Try::Tiny;
@@ -57,7 +57,6 @@ my %_shatests = (
 sub have_sha {
   # if we have Crypt::Passwd::XS, just use that:
   return 1 if have_passwd_xs();
-
   # else determine (the slow way) if SHA256/512 are available via libc:
   my $rate = $_[0] || 512;
   my $type = "sha$rate";
@@ -153,6 +152,7 @@ sub mkpasswd {
       $salt = $saltgen->(bcrypt => $opts{strong});
       my $bsettings = join '', '$2a$', $cost, '$', $salt;
 
+      # bcrypt returns from here; everything else depends on have_passwd_xs
       return bcrypt($pwd, $bsettings)
     }
 
@@ -189,10 +189,10 @@ sub _eq {
   my $unequal = ! (length $orig == length $created);
   my $n = 0;
   no warnings 'substr';
-  while ($n < length $created) {
-    my $schr = substr $orig, $n, 1;
+  while ($n < length $orig) {
+    my $schr = substr $created, $n, 1;
     $unequal = 1
-      if substr($created, $n, 1) ne (defined $schr ? $schr : '');
+      if substr($orig, $n, 1) ne (defined $schr ? $schr : '');
     ++$n;
   }
   ! $unequal
@@ -233,7 +233,7 @@ __END__
 
 =head1 NAME
 
-App::bmkpasswd - bcrypt-capable mkpasswd(1) and exported helpers
+App::bmkpasswd - bcrypt-capable mkpasswd(1) and exported bcrypt interface
 
 =head1 SYNOPSIS
 
@@ -267,14 +267,12 @@ App::bmkpasswd - bcrypt-capable mkpasswd(1) and exported helpers
 B<App::bmkpasswd> is a bcrypt-enabled C<mkpasswd> implementation.
 
 Helper functions are also exported for use in other applications; see
-L</EXPORTED>.
-L<Crypt::Bcrypt::Easy> provides an easier bcrypt-specific
-programmatic interface for Perl programmers.
+L</EXPORTED> -- however L<Crypt::Bcrypt::Easy> (from this distribution)
+provides an easier bcrypt-specific programmatic interface for Perl
+programmers.
 
 See C<bmkpasswd --help> for command-line usage information.
 
-Uses L<Crypt::Eksblowfish::Bcrypt> for bcrypted passwords.
-
 Bcrypt leverages a work-cost factor allowing hash generation
 to become configurably slower as computers get faster, thereby
 impeding brute-force hash generation attempts.
@@ -285,15 +283,17 @@ B<SHA-256> and B<SHA-512> are supported if available. SHA support requires
 either L<Crypt::Passwd::XS> or a system crypt() that can handle SHA (such as
 glibc-2.7+ or modern FreeBSD builds).
 
+This module uses L<Crypt::Eksblowfish::Bcrypt> as a back-end.
+
 Uses L<Bytes::Random::Secure::Tiny> to generate random salts. Strongly-random salts
 can also be enabled; see L</mkpasswd>.
 
 =head1 EXPORTED
 
-L<Crypt::Bcrypt::Easy> provides an easier programmatic interface, if you're
-only interested in generating bcrypt passwords.  If you'd like to make use of
-other password types, you can use the exported B<mkpasswd> and B<passwdcmp>
-functions:
+L<Crypt::Bcrypt::Easy> provides an easier programmatic interface, but only
+generates bcrypt (although it can validate any supported type).  If you would
+like to create crypted passwords using other methods, you can use the exported
+B<mkpasswd> and B<passwdcmp> functions:
 
   # Import selectively:
   use App::bmkpasswd 'mkpasswd', 'passwdcmp';
@@ -307,7 +307,7 @@ flexible import options. See the L<Exporter::Tiny> docs for details.
 
 Compare a password against a hash.
 
-  if ( passwdcmp($plaintext, $crypted) ) {
+  if ( passwdcmp($plaintext => $crypted) ) {
     ## Successful match
   } else {
     ## Failed match
@@ -412,7 +412,7 @@ Added in C<v2.6.1>.
 
 =head1 AUTHOR
 
-Jon Portnoy <avenj@cobaltirc.org>
+Jon Portnoy <jon@portnoy.me>
 
 =for Pod::Coverage have_\w+ get_\w+
 
